@@ -1,35 +1,31 @@
 """Define the MyQ API."""
 import asyncio
-import logging
-from bs4 import BeautifulSoup
 from datetime import datetime, timedelta
-from typing import Dict, Optional, Union, Tuple
-from urllib.parse import urlsplit, parse_qs
-from random import choices
-import string
+import logging
+from typing import Dict, List, Optional, Tuple, Union
+from urllib.parse import parse_qs, urlsplit
 
-from aiohttp import ClientSession, ClientResponse
+from aiohttp import ClientResponse, ClientSession
 from aiohttp.client_exceptions import ClientError, ClientResponseError
+from bs4 import BeautifulSoup
 from pkce import generate_code_verifier, get_code_challenge
+from yarl import URL
 
+from .account import MyQAccount
 from .const import (
     ACCOUNTS_ENDPOINT,
-    DEVICES_ENDPOINT,
-    DEVICE_FAMILY_GARAGEDOOR,
-    DEVICE_FAMILY_GATEWAY,
-    DEVICE_FAMLY_LAMP,
-    OAUTH_CLIENT_ID,
-    OAUTH_CLIENT_SECRET,
     OAUTH_AUTHORIZE_URI,
     OAUTH_BASE_URI,
-    OAUTH_TOKEN_URI,
+    OAUTH_CLIENT_ID,
+    OAUTH_CLIENT_SECRET,
     OAUTH_REDIRECT_URI,
+    OAUTH_TOKEN_URI,
 )
 from .device import MyQDevice
-from .errors import AuthenticationError, InvalidCredentialsError, RequestError
+from .errors import AuthenticationError, InvalidCredentialsError, MyQError, RequestError
 from .garagedoor import MyQGaragedoor
 from .lamp import MyQLamp
-from .request import MyQRequest, REQUEST_METHODS
+from .request import REQUEST_METHODS, MyQRequest
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -45,13 +41,10 @@ class API:  # pylint: disable=too-many-instance-attributes
         username: str,
         password: str,
         websession: ClientSession = None,
-        useragent: Optional[str] = None,
     ) -> None:
         """Initialize."""
         self.__credentials = {"username": username, "password": password}
-        self._myqrequests = MyQRequest(
-            websession or ClientSession(), useragent=useragent
-        )
+        self._myqrequests = MyQRequest(websession or ClientSession())
         self._authentication_task = None  # type:Optional[asyncio.Task]
         self._codeverifier = None  # type: Optional[str]
         self._invalid_credentials = False  # type: bool
@@ -63,36 +56,40 @@ class API:  # pylint: disable=too-many-instance-attributes
             None,
         )  # type: Tuple[Optional[str], Optional[datetime], Optional[datetime]]
 
-        self.accounts = {}  # type: Dict[str, str]
-        self.devices = {}  # type: Dict[str, MyQDevice]
+        self.accounts = {}  # type: Dict[str, MyQAccount]
         self.last_state_update = None  # type: Optional[datetime]
 
+    @property
+    def devices(self) -> Dict[str, Union[MyQDevice, MyQGaragedoor, MyQLamp]]:
+        """Return all devices."""
+        devices = {}
+        for account in self.accounts.values():
+            devices.update(account.devices)
+        return devices
+
     @property
     def covers(self) -> Dict[str, MyQGaragedoor]:
         """Return only those devices that are covers."""
-        return {
-            device_id: device
-            for device_id, device in self.devices.items()
-            if device.device_json["device_family"] == DEVICE_FAMILY_GARAGEDOOR
-        }
+        covers = {}
+        for account in self.accounts.values():
+            covers.update(account.covers)
+        return covers
 
     @property
-    def lamps(self) -> Dict[str, MyQDevice]:
+    def lamps(self) -> Dict[str, MyQLamp]:
         """Return only those devices that are covers."""
-        return {
-            device_id: device
-            for device_id, device in self.devices.items()
-            if device.device_json["device_family"] == DEVICE_FAMLY_LAMP
-        }
+        lamps = {}
+        for account in self.accounts.values():
+            lamps.update(account.lamps)
+        return lamps
 
     @property
     def gateways(self) -> Dict[str, MyQDevice]:
         """Return only those devices that are covers."""
-        return {
-            device_id: device
-            for device_id, device in self.devices.items()
-            if device.device_json["device_family"] == DEVICE_FAMILY_GATEWAY
-        }
+        gateways = {}
+        for account in self.accounts.values():
+            gateways.update(account.gateways)
+        return gateways
 
     @property
     def _code_verifier(self) -> str:
@@ -102,27 +99,91 @@ class API:  # pylint: disable=too-many-instance-attributes
 
     @property
     def username(self) -> str:
+        """Username used to authenticate with on MyQ
+
+        Returns:
+            str: username
+        """
         return self.__credentials["username"]
 
     @username.setter
-    def username(self, username: str) -> None:
+    def username(self, username: str):
+        """Set username to use for authentication
+
+        Args:
+            username (str): Username to authenticate with
+        """
         self._invalid_credentials = False
         self.__credentials["username"] = username
 
     @property
-    def password(self) -> None:
+    def password(self) -> Optional[str]:
+        """Will return None, password retrieval is not possible
+
+        Returns:
+            None
+        """
         return None
 
     @password.setter
-    def password(self, password: str) -> None:
+    def password(self, password: str):
+        """Set password used to authenticate with
+
+        Args:
+            password (str): password
+        """
         self._invalid_credentials = False
         self.__credentials["password"] = password
 
+    async def _authentication_task_completed(self) -> None:
+        # If we had something for an authentication task and
+        # it is done then get the result and clear it out.
+        if self._authentication_task is not None:
+            authentication_task = await self.authenticate(wait=False)
+            if authentication_task.done():
+                _LOGGER.debug(
+                    "Scheduled token refresh completed, ensuring no exception."
+                )
+                self._authentication_task = None
+                try:
+                    # Get the result so any exception is raised.
+                    authentication_task.result()
+                except asyncio.CancelledError:
+                    pass
+                except (RequestError, AuthenticationError) as auth_err:
+                    message = f"Scheduled token refresh failed: {str(auth_err)}"
+                    _LOGGER.debug(message)
+
+    async def _refresh_token(self) -> None:
+        # Check if token has to be refreshed.
+        if (
+            self._security_token[1] is None
+            or self._security_token[1] <= datetime.utcnow()
+        ):
+            # Token has to be refreshed, get authentication task if running otherwise
+            # start a new one.
+            if self._security_token[0] is None:
+                # Wait for authentication task to be completed.
+                _LOGGER.debug(
+                    "Waiting for updated token, last refresh was %s",
+                    self._security_token[2],
+                )
+                try:
+                    await self.authenticate(wait=True)
+                except AuthenticationError as auth_err:
+                    message = f"Error trying to re-authenticate to myQ service: {str(auth_err)}"
+                    _LOGGER.debug(message)
+                    raise AuthenticationError(message) from auth_err
+            else:
+                # We still have a token, we can continue this request with
+                # that token and schedule task to refresh token unless one is already running
+                await self.authenticate(wait=False)
+
     async def request(
         self,
         method: str,
         returns: str,
-        url: str,
+        url: Union[URL, str],
         websession: ClientSession = None,
         headers: dict = None,
         params: dict = None,
@@ -130,7 +191,7 @@ class API:  # pylint: disable=too-many-instance-attributes
         json: dict = None,
         allow_redirects: bool = True,
         login_request: bool = False,
-    ) -> Tuple[ClientResponse, Union[dict, str, None]]:
+    ) -> Tuple[Optional[ClientResponse], Optional[Union[dict, str]]]:
         """Make a request."""
 
         # Determine the method to call based on what is to be returned.
@@ -158,12 +219,12 @@ class API:  # pylint: disable=too-many-instance-attributes
                     f"Error requesting data from {url}: {err.status} - {err.message}"
                 )
                 _LOGGER.debug(message)
-                raise RequestError(message)
+                raise RequestError(message) from err
 
             except ClientError as err:
                 message = f"Error requesting data from {url}: {str(err)}"
                 _LOGGER.debug(message)
-                raise RequestError(message)
+                raise RequestError(message) from err
 
         # The MyQ API can time out if multiple concurrent requests are made, so
         # ensure that only one gets through at a time.
@@ -171,54 +232,20 @@ class API:  # pylint: disable=too-many-instance-attributes
         # we're sending the request anyways as we know there is no active request now.
         async with self._lock:
 
-            # If we had something for an authentication task and it is done then get the result and clear it out.
-            if self._authentication_task is not None:
-                authentication_task = await self.authenticate(wait=False)
-                if authentication_task.done():
-                    _LOGGER.debug(
-                        "Scheduled token refresh completed, ensuring no exception."
-                    )
-                    self._authentication_task = None
-                    try:
-                        # Get the result so any exception is raised.
-                        authentication_task.result()
-                    except asyncio.CancelledError:
-                        pass
-                    except (RequestError, AuthenticationError) as auth_err:
-                        message = f"Scheduled token refresh failed: {str(auth_err)}"
-                        _LOGGER.debug(message)
+            # Check if an authentication task was running and if so, if it has completed.
+            await self._authentication_task_completed()
 
-            # Check if token has to be refreshed.
-            if (
-                self._security_token[1] is None
-                or self._security_token[1] <= datetime.utcnow()
-            ):
-                # Token has to be refreshed, get authentication task if running otherwise start a new one.
-                if self._security_token[0] is None:
-                    # Wait for authentication task to be completed.
-                    _LOGGER.debug(
-                        f"Waiting for updated token, last refresh was {self._security_token[2]}"
-                    )
-                    try:
-                        await self.authenticate(wait=True)
-                    except AuthenticationError as auth_err:
-                        message = f"Error trying to re-authenticate to myQ service: {str(auth_err)}"
-                        _LOGGER.debug(message)
-                        raise AuthenticationError(message)
-                else:
-                    # We still have a token, we can continue this request with that token and schedule
-                    # task to refresh token unless one is already running
-                    await self.authenticate(wait=False)
+            # Check if token has to be refreshed and start task to refresh, wait if required now.
+            await self._refresh_token()
 
             if not headers:
                 headers = {}
 
             headers["Authorization"] = self._security_token[0]
 
-            _LOGGER.debug(f"Sending {method} request to {url}.")
-            # Do the request
-            try:
-                # First try
+            _LOGGER.debug("Sending %s request to %s.", method, url)
+            # Do the request. We will try 2 times based on response.
+            for attempt in range(2):
                 try:
                     return await call_method(
                         method=method,
@@ -231,51 +258,30 @@ class API:  # pylint: disable=too-many-instance-attributes
                         allow_redirects=allow_redirects,
                     )
                 except ClientResponseError as err:
-                    # Handle only if status is 401, we then re-authenticate and retry the request
-                    if err.status == 401:
-                        self._security_token = (None, None, self._security_token[2])
-                        _LOGGER.debug("Status 401 received, re-authenticating.")
-                        try:
-                            await self.authenticate(wait=True)
-                        except AuthenticationError as auth_err:
-                            # Raise authentication error, we need a new token to continue and not getting it right
-                            # now.
-                            message = f"Error trying to re-authenticate to myQ service: {str(auth_err)}"
+                    message = f"Error requesting data from {url}: {err.status} - {err.message}"
+
+                    if getattr(err, "status") and err.status == 401:
+                        if attempt == 0:
+                            self._security_token = (None, None, self._security_token[2])
+                            _LOGGER.debug("Status 401 received, re-authenticating.")
+
+                            await self._refresh_token()
+                        else:
+                            # Received unauthorized again,
+                            # reset token and start task to get a new one.
                             _LOGGER.debug(message)
-                            raise AuthenticationError(message)
+                            self._security_token = (None, None, self._security_token[2])
+                            await self.authenticate(wait=False)
+                            raise AuthenticationError(message) from err
                     else:
-                        # Some other error, re-raise.
-                        raise err
+                        _LOGGER.debug(message)
+                        raise RequestError(message) from err
 
-                # Re-authentication worked, resend request that had failed.
-                return await call_method(
-                    method=method,
-                    url=url,
-                    websession=websession,
-                    headers=headers,
-                    params=params,
-                    data=data,
-                    json=json,
-                    allow_redirects=allow_redirects,
-                )
-
-            except ClientResponseError as err:
-                message = (
-                    f"Error requesting data from {url}: {err.status} - {err.message}"
-                )
-                _LOGGER.debug(message)
-                if getattr(err, "status") and err.status == 401:
-                    # Received unauthorized, reset token and start task to get a new one.
-                    self._security_token = (None, None, self._security_token[2])
-                    await self.authenticate(wait=False)
-                    raise AuthenticationError(message)
-
-                raise RequestError(message)
-
-            except ClientError as err:
-                message = f"Error requesting data from {url}: {str(err)}"
-                _LOGGER.debug(message)
-                raise RequestError(message)
+                except ClientError as err:
+                    message = f"Error requesting data from {url}: {str(err)}"
+                    _LOGGER.debug(message)
+                    raise RequestError(message) from err
+        return None, None
 
     async def _oauth_authenticate(self) -> Tuple[str, int]:
 
@@ -305,7 +311,8 @@ class API:  # pylint: disable=too-many-instance-attributes
             _LOGGER.debug("Scanning login page for fields to return")
             soup = BeautifulSoup(html, "html.parser")
 
-            # Go through all potential forms in the page returned. This is in case multiple forms are returned.
+            # Go through all potential forms in the page returned.
+            # This is in case multiple forms are returned.
             forms = soup.find_all("form")
             data = {}
             for form in forms:
@@ -420,18 +427,26 @@ class API:  # pylint: disable=too-many-instance-attributes
                 login_request=True,
             )
 
+            if not isinstance(data, dict):
+                raise MyQError(
+                    f"Received object data of type {type(data)} but expecting type dict"
+                )
+
             token = f"{data.get('token_type')} {data.get('access_token')}"
             try:
                 expires = int(data.get("expires_in", DEFAULT_TOKEN_REFRESH))
             except ValueError:
                 _LOGGER.debug(
-                    f"Expires {data.get('expires_in')} received is not an integer, using default."
+                    "Expires %s received is not an integer, using default.",
+                    data.get("expires_in"),
                 )
                 expires = DEFAULT_TOKEN_REFRESH * 2
 
         if expires < DEFAULT_TOKEN_REFRESH * 2:
             _LOGGER.debug(
-                f"Expires {expires} is less then default {DEFAULT_TOKEN_REFRESH}, setting to default instead."
+                "Expires %s is less then default %s, setting to default instead.",
+                expires,
+                DEFAULT_TOKEN_REFRESH,
             )
             expires = DEFAULT_TOKEN_REFRESH * 2
 
@@ -452,7 +467,7 @@ class API:  # pylint: disable=too-many-instance-attributes
         if self._authentication_task is None:
             # No authentication task is currently running, start one
             _LOGGER.debug(
-                f"Scheduling token refresh, last refresh was {self._security_token[2]}"
+                "Scheduling token refresh, last refresh was %s", self._security_token[2]
             )
             self._authentication_task = asyncio.create_task(
                 self._authenticate(), name="MyQ_Authenticate"
@@ -462,10 +477,10 @@ class API:  # pylint: disable=too-many-instance-attributes
             try:
                 await self._authentication_task
             except (RequestError, AuthenticationError) as auth_err:
-                # Raise authentication error, we need a new token to continue and not getting it right
-                # now.
+                # Raise authentication error, we need a new token to continue
+                # and not getting it right now.
                 self._authentication_task = None
-                raise AuthenticationError(str(auth_err))
+                raise AuthenticationError(str(auth_err)) from auth_err
             self._authentication_task = None
 
         return self._authentication_task
@@ -481,14 +496,14 @@ class API:  # pylint: disable=too-many-instance-attributes
                 "Authentication response did not contain a security token yet one is expected."
             )
 
-        _LOGGER.debug(f"Received token that will expire in {expires} seconds")
+        _LOGGER.debug("Received token that will expire in %s seconds", expires)
         self._security_token = (
             token,
             datetime.utcnow() + timedelta(seconds=int(expires / 2)),
             datetime.now(),
         )
 
-    async def _get_accounts(self) -> Optional[dict]:
+    async def _get_accounts(self) -> List:
 
         _LOGGER.debug("Retrieving account information")
 
@@ -497,104 +512,15 @@ class API:  # pylint: disable=too-many-instance-attributes
             method="get", returns="json", url=ACCOUNTS_ENDPOINT
         )
 
-        if accounts_resp is not None and accounts_resp.get("accounts") is not None:
-            accounts = {}
-            for account in accounts_resp["accounts"]:
-                account_id = account.get("id")
-                if account_id is not None:
-                    _LOGGER.debug(
-                        f"Got account {account_id} with name {account.get('name')}"
-                    )
-                    accounts.update({account_id: account.get("name")})
-        else:
-            _LOGGER.debug(f"No accounts found")
-            accounts = None
+        if accounts_resp is not None and not isinstance(accounts_resp, dict):
+            raise MyQError(
+                f"Received object accounts_resp of type {type(accounts_resp)}"
+                f"but expecting type dict"
+            )
 
-        return accounts
+        return accounts_resp.get("accounts", []) if accounts_resp is not None else []
 
-    async def _get_devices_for_account(self, account) -> None:
-
-        _LOGGER.debug(f"Retrieving devices for account {self.accounts[account]}")
-
-        _, devices_resp = await self.request(
-            method="get",
-            returns="json",
-            url=DEVICES_ENDPOINT.format(account_id=account),
-        )
-
-        state_update_timestmp = datetime.utcnow()
-        if devices_resp is not None and devices_resp.get("items") is not None:
-            for device in devices_resp.get("items"):
-                serial_number = device.get("serial_number")
-                if serial_number is None:
-                    _LOGGER.debug(
-                        f"No serial number for device with name {device.get('name')}."
-                    )
-                    continue
-
-                if serial_number in self.devices:
-                    _LOGGER.debug(
-                        f"Updating information for device with serial number {serial_number}"
-                    )
-                    myqdevice = self.devices[serial_number]
-
-                    # When performing commands we might update the state temporary, need to ensure
-                    # that the state is not set back to something else if MyQ does not yet have updated
-                    # state
-                    last_update = myqdevice.device_json["state"].get("last_update")
-                    myqdevice.device_json = device
-
-                    if (
-                        myqdevice.device_json["state"].get("last_update") is not None
-                        and myqdevice.device_json["state"].get("last_update")
-                        != last_update
-                    ):
-                        # MyQ has updated device state, reset ours ensuring we have the one from MyQ.
-                        myqdevice.state = None
-                        _LOGGER.debug(
-                            f"State for device {myqdevice.name} was updated to {myqdevice.state}"
-                        )
-
-                    myqdevice.state_update = state_update_timestmp
-                else:
-                    if device.get("device_family") == DEVICE_FAMILY_GARAGEDOOR:
-                        _LOGGER.debug(
-                            f"Adding new garage door with serial number {serial_number}"
-                        )
-                        self.devices[serial_number] = MyQGaragedoor(
-                            api=self,
-                            account=account,
-                            device_json=device,
-                            state_update=state_update_timestmp,
-                        )
-                    elif device.get("device_family") == DEVICE_FAMLY_LAMP:
-                        _LOGGER.debug(
-                            f"Adding new lamp with serial number {serial_number}"
-                        )
-                        self.devices[serial_number] = MyQLamp(
-                            api=self,
-                            account=account,
-                            device_json=device,
-                            state_update=state_update_timestmp,
-                        )
-                    elif device.get("device_family") == DEVICE_FAMILY_GATEWAY:
-                        _LOGGER.debug(
-                            f"Adding new gateway with serial number {serial_number}"
-                        )
-                        self.devices[serial_number] = MyQDevice(
-                            api=self,
-                            account=account,
-                            device_json=device,
-                            state_update=state_update_timestmp,
-                        )
-                    else:
-                        _LOGGER.warning(
-                            f"Unknown device family {device.get('device_family')}"
-                        )
-        else:
-            _LOGGER.debug(f"No devices found for account {self.accounts[account]}")
-
-    async def update_device_info(self, for_account: str = None) -> None:
+    async def update_device_info(self) -> None:
         """Get up-to-date device info."""
         # The MyQ API can time out if state updates are too frequent; therefore,
         # if back-to-back requests occur within a threshold, respond to only the first
@@ -607,102 +533,74 @@ class API:  # pylint: disable=too-many-instance-attributes
                 self.last_state_update + DEFAULT_STATE_UPDATE_INTERVAL
             )
 
-            # Ensure we're within our minimum update interval AND update request is not for a specific device
-            if call_dt < next_available_call_dt and for_account is None:
-                _LOGGER.debug(
-                    "Ignoring device update request as it is within throttle window"
-                )
+            # Ensure we're within our minimum update interval AND
+            # update request is not for a specific device
+            if call_dt < next_available_call_dt:
+                _LOGGER.debug("Ignoring update request as it is within throttle window")
                 return
 
-            _LOGGER.debug("Updating device information")
+            _LOGGER.debug("Updating account information")
             # If update request is for a specific account then do not retrieve account information.
-            if for_account is None:
-                self.accounts = await self._get_accounts()
+            accounts = await self._get_accounts()
 
-                if self.accounts is None:
-                    _LOGGER.debug(f"No accounts found")
-                    self.devices = {}
-                    accounts = {}
-                else:
-                    accounts = self.accounts
-            else:
-                # Request is for specific account, thus restrict retrieval to the 1 account.
-                if self.accounts.get(for_account) is None:
-                    # Checking to ensure we know the account, but this should never happen.
-                    _LOGGER.debug(
-                        f"Unable to perform update request for account {for_account} as it is not known."
-                    )
-                    accounts = {}
-                else:
-                    accounts = {for_account: self.accounts.get(for_account)}
+            if len(accounts) == 0:
+                _LOGGER.debug("No accounts found")
+                self.accounts = {}
+                return
 
             for account in accounts:
-                await self._get_devices_for_account(account=account)
+                print(account)
+                account_id = account.get("id")
+                if account_id is not None:
+                    if self.accounts.get(account_id):
+                        # Account already existed, update information.
+                        _LOGGER.debug(
+                            "Updating account %s with name %s",
+                            account_id,
+                            account.get("name"),
+                        )
 
-            # Update our last update timestamp UNLESS this is for a specific account
-            if for_account is None:
-                self.last_state_update = datetime.utcnow()
+                        self.accounts.get(account_id).account_json = account
+                    else:
+                        # This is a new account.
+                        _LOGGER.debug(
+                            "New account %s with name %s",
+                            account_id,
+                            account.get("name"),
+                        )
+                        self.accounts.update(
+                            {account_id: MyQAccount(api=self, account_json=account)}
+                        )
+
+                    # Perform a device update for this account.
+                    await self.accounts.get(account_id).update()
+
+            self.last_state_update = datetime.utcnow()
 
 
-async def login(username: str, password: str, websession: ClientSession = None) -> API:
+async def login(
+    username: str,
+    password: str,
+    websession: ClientSession = None,
+    auth_only: bool = False,
+) -> API:
     """Log in to the API."""
 
-    # Retrieve user agent from GitHub if not provided for login.
-    _LOGGER.debug("No user agent provided, trying to retrieve from GitHub.")
-    url = f"https://raw.githubusercontent.com/arraylabs/pymyq/master/.USER_AGENT"
-
-    try:
-        async with ClientSession() as session:
-            async with session.get(url) as resp:
-                useragent = await resp.text()
-                resp.raise_for_status()
-                _LOGGER.debug(f"Retrieved user agent {useragent} from GitHub.")
-
-    except ClientError as exc:
-        # Default user agent to random string with length of 5 if failure to retrieve it from GitHub.
-        useragent = "#RANDOM:5"
-        _LOGGER.warning(
-            f"Failed retrieving user agent from GitHub, will use randomized user agent "
-            f"instead: {str(exc)}"
-        )
-
-    # Check if value for useragent is to create a random user agent.
-    useragent_list = useragent.split(":")
-    if useragent_list[0] == "#RANDOM":
-        # Create a random string, check if length is provided for the random string, if not then default is 5.
-        try:
-            randomlength = int(useragent_list[1]) if len(useragent_list) == 2 else 5
-        except ValueError:
-            _LOGGER.debug(
-                f"Random length value {useragent_list[1]} in user agent {useragent} is not an integer. "
-                f"Setting to 5 instead."
-            )
-            randomlength = 5
-
-        # Create the random user agent.
-        useragent = "".join(
-            choices(string.ascii_letters + string.digits, k=randomlength)
-        )
-        _LOGGER.debug(f"User agent set to randomized value: {useragent}.")
-
     # Set the user agent in the headers.
-    api = API(
-        username=username, password=password, websession=websession, useragent=useragent
-    )
+    api = API(username=username, password=password, websession=websession)
     _LOGGER.debug("Performing initial authentication into MyQ")
     try:
         await api.authenticate(wait=True)
     except InvalidCredentialsError as err:
-        _LOGGER.error(
-            f"Username and/or password are invalid. Update username/password."
-        )
+        _LOGGER.error("Username and/or password are invalid. Update username/password.")
         raise err
     except AuthenticationError as err:
-        _LOGGER.error(f"Authentication failed: {str(err)}")
+        _LOGGER.error("Authentication failed: %s", str(err))
         raise err
 
-    # Retrieve and store initial set of devices:
-    _LOGGER.debug("Retrieving MyQ information")
-    await api.update_device_info()
+    if not auth_only:
+        # Retrieve and store initial set of devices:
+        _LOGGER.debug("Retrieving MyQ information")
+        await api.update_device_info()
 
     return api
